@@ -2,14 +2,14 @@
  *
  *  Name:       variable.c
  *
- *  Version:    2.7-1
+ *  Version:    2.10-2
  *
  *  Purpose:    NetCDF variable functions for RNetCDF
  *
  *  Author:     Pavel Michna (rnetcdf-devel@bluewin.ch)
  *              Milton Woods (miltonjwoods@gmail.com)
  *
- *  Copyright (C) 2004-2023 Pavel Michna and Milton Woods.
+ *  Copyright (C) 2004-2025 Pavel Michna and Milton Woods.
  *
  *=============================================================================*
  *
@@ -809,7 +809,7 @@ R_nc_inq_var (SEXP nc, SEXP var)
       UNPROTECT(2);
 #  endif
     } else {
-      error (nc_strerror (status));
+      error ("%s", nc_strerror (status));
     }
 #else
     SET_VECTOR_ELT (result, 14, R_NilValue);
