@@ -2,14 +2,14 @@
 #
 #  Name:       RNetCDF-test.R
 #
-#  Version:    2.8-1
+#  Version:    2.10-2
 #
 #  Purpose:    Test functions to the NetCDF interface for R.
 #
 #  Author:     Pavel Michna (rnetcdf-devel@bluewin.ch)
 #              Milton Woods (miltonjwoods@gmail.com)
 #
-#  Copyright (C) 2004-2023 Pavel Michna and Milton Woods.
+#  Copyright (C) 2004-2025 Pavel Michna and Milton Woods.
 #
 #===============================================================================#
 #
@@ -119,7 +119,7 @@ for (format in c("classic","offset64","data64","classic4","netcdf4")) {
   # Show library version:
   libvers <- file.inq.nc(nc)$libvers
   cat("Version of netcdf library ... ", libvers, "\n")
-  verstr <- sub(' .*', '', file.inq.nc(nc)$libvers)
+  verstr <- sub('([[:digit:]\\.]+).*', '\\1', libvers)
 
   nstation <- 5
   ntime <- 2
@@ -1412,6 +1412,10 @@ if (!cfg$udunits) {
   y <- utcal.nc("hours since 1900-01-01 00:00:00 +01:00", c(0:5), type="c")
   tally <- testfun(x,y,tally)
 
+  cat("utcal.nc - error for unknown units ...")
+  x <- try(utcal.nc("unknown", 1), silent=TRUE)
+  tally <- testfun(inherits(x, "try-error"), TRUE, tally)
+
   cat("utinvcal.nc - numeric values ...")
   x <- 6.416667
   y <- utinvcal.nc("hours since 1900-01-01 00:00:00 +01:00", c(1900,1,1,5,25,0))
@@ -1428,6 +1432,11 @@ if (!cfg$udunits) {
 	   ISOdatetime(1900,1,1,5,25,0,tz="UTC"))
   tally <- testfun(x,y,tally)
 
+  cat("utinvcal.nc - error for bad values ...")
+  x <- try(utinvcal.nc("hours since 1900-01-01 00:00:00 +01:00",
+                       "1900-01-01 24:61:61"), silent=TRUE)
+  tally <- testfun(inherits(x, "try-error"), TRUE, tally)
+
 }
 
 #-------------------------------------------------------------------------------#
